
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.012.
use strict;
use warnings;

use Module::Build 0.3601;
use lib qw{inc}; use Archive::Libarchive::Any::ModuleBuild;

my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "Perl bindings to libarchive",
  "dist_author" => [
    "Graham Ollis <plicease\@cpan.org>"
  ],
  "dist_name" => "Archive-Libarchive-Any",
  "dist_version" => "0.06",
  "license" => "perl",
  "module_name" => "Archive::Libarchive::Any",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "perl" => "5.008"
  },
  "script_files" => [],
  "test_requires" => {
    "Alien::Libarchive" => 0,
    "File::Basename" => 0,
    "File::Spec" => 0,
    "File::Temp" => 0,
    "FindBin" => 0,
    "Test::More" => 0,
    "open" => 0,
    "utf8" => 0
  }
);


my %fallback_build_requires = (
  "Alien::Libarchive" => 0,
  "File::Basename" => 0,
  "File::Spec" => 0,
  "File::Temp" => 0,
  "FindBin" => 0,
  "Module::Build" => "0.3601",
  "Test::More" => 0,
  "open" => 0,
  "utf8" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Archive::Libarchive::Any::ModuleBuild->new(%module_build_args);

$build->create_build_script;
